==> pmml-model-gwt-1.1.11-sources.jar: org/dmg/pmml/KohonenMap.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.FloatAdapter;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="coord1" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord2" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord3" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "KohonenMap", namespace = "http://www.dmg.org/PMML-4_2")
public class KohonenMap
    extends PMMLObject
    implements HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<Extension> extensions;
    @XmlAttribute(name = "coord1")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    protected Double coord1;
    @XmlAttribute(name = "coord2")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    protected Double coord2;
    @XmlAttribute(name = "coord3")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    protected Double coord3;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the coord1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord1() {
        return coord1;
    }

    /**
     * Sets the value of the coord1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCoord1(Double value) {
        this.coord1 = value;
    }

    /**
     * Gets the value of the coord2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord2() {
        return coord2;
    }

    /**
     * Sets the value of the coord2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCoord2(Double value) {
        this.coord2 = value;
    }

    /**
     * Gets the value of the coord3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord3() {
        return coord3;
    }

    /**
     * Sets the value of the coord3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCoord3(Double value) {
        this.coord3 = value;
    }

    public KohonenMap withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public KohonenMap withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public KohonenMap withCoord1(Double value) {
        setCoord1(value);
        return this;
    }

    public KohonenMap withCoord2(Double value) {
        setCoord2(value);
        return this;
    }

    public KohonenMap withCoord3(Double value) {
        setCoord3(value);
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.2.0-sources.jar: org/dmg/pmml/KohonenMap.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.dmg.pmml.adapters.FloatAdapter;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="coord1" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord2" type="{http://www.w3.org/2001/XMLSchema}float" />
 *       &lt;attribute name="coord3" type="{http://www.w3.org/2001/XMLSchema}float" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "KohonenMap", namespace = "http://www.dmg.org/PMML-4_2")
public class KohonenMap
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions
{

    @XmlAttribute(name = "coord1")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    private Double coord1;
    @XmlAttribute(name = "coord2")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    private Double coord2;
    @XmlAttribute(name = "coord3")
    @XmlJavaTypeAdapter(FloatAdapter.class)
    @XmlSchemaType(name = "float")
    private Double coord3;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    private List<Extension> extensions;

    /**
     * Gets the value of the coord1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord1() {
        return coord1;
    }

    /**
     * Sets the value of the coord1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public KohonenMap setCoord1(Double coord1) {
        this.coord1 = coord1;
        return this;
    }

    /**
     * Gets the value of the coord2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord2() {
        return coord2;
    }

    /**
     * Sets the value of the coord2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public KohonenMap setCoord2(Double coord2) {
        this.coord2 = coord2;
        return this;
    }

    /**
     * Gets the value of the coord3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Double getCoord3() {
        return coord3;
    }

    /**
     * Sets the value of the coord3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public KohonenMap setCoord3(Double coord3) {
        this.coord3 = coord3;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public KohonenMap addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
            status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
